@@ -9,6 +9,8 @@ use Scalar::Util 'blessed';
 
 our @EXPORT_OK = ('c');
 
+sub TO_JSON { [@{shift()}] }
+
 sub c { __PACKAGE__->new(@_) }
 
 sub compact {
@@ -25,18 +27,18 @@ sub each {
 }
 
 sub first {
-  my ($self, $cb) = @_;
+  my ($self, $cb) = (shift, shift);
   return $self->[0] unless $cb;
-  return List::Util::first { $cb->($_) } @$self if ref $cb eq 'CODE';
-  return List::Util::first { $_ =~ $cb } @$self;
+  return List::Util::first { $_ =~ $cb } @$self if ref $cb eq 'Regexp';
+  return List::Util::first { $_->$cb(@_) } @$self;
 }
 
 sub flatten { $_[0]->new(_flatten(@{$_[0]})) }
 
 sub grep {
-  my ($self, $cb) = @_;
-  return $self->new(grep { $cb->($_) } @$self) if ref $cb eq 'CODE';
-  return $self->new(grep { $_ =~ $cb } @$self);
+  my ($self, $cb) = (shift, shift);
+  return $self->new(grep { $_ =~ $cb } @$self) if ref $cb eq 'Regexp';
+  return $self->new(grep { $_->$cb(@_) } @$self);
 }
 
 sub join {
@@ -91,8 +93,10 @@ sub tap { shift->Mojo::Base::tap(@_) }
 sub to_array { [@{shift()}] }
 
 sub uniq {
+  my ($self, $cb) = (shift, shift);
   my %seen;
-  return $_[0]->new(grep { !$seen{$_}++ } @{$_[0]});
+  return $self->new(grep { !$seen{$_->$cb(@_)}++ } @$self) if $cb;
+  return $self->new(grep { !$seen{$_}++ } @$self);
 }
 
 sub _flatten {
@@ -152,6 +156,12 @@ Construct a new array-based L<Mojo::Collection> object.
 
 L<Mojo::Collection> implements the following methods.
 
+=head2 TO_JSON
+
+  my $array = $collection->TO_JSON;
+
+Alias for L</"to_array">.
+
 =head2 compact
 
   my $new = $collection->compact;
@@ -167,7 +177,7 @@ string.
   my @elements = $collection->each;
   $collection  = $collection->each(sub {...});
 
-Evaluate callback for each element in collection or return all elements as a
+Evaluate callback for each element in collection, or return all elements as a
 list if none has been provided. The element will be the first argument passed
 to the callback and is also available as C<$_>.
 
@@ -182,11 +192,16 @@ to the callback and is also available as C<$_>.
   my $first = $collection->first;
   my $first = $collection->first(qr/foo/);
   my $first = $collection->first(sub {...});
+  my $first = $collection->first($method);
+  my $first = $collection->first($method, @args);
 
-Evaluate regular expression or callback for each element in collection and
-return the first one that matched the regular expression, or for which the
-callback returned true. The element will be the first argument passed to the
-callback and is also available as C<$_>.
+Evaluate regular expression/callback for, or call method on, each element in
+collection and return the first one that matched the regular expression, or for
+which the callback/method returned true. The element will be the first argument
+passed to the callback and is also available as C<$_>.
+
+  # Longer version
+  my $first = $collection->first(sub { $_->$method(@args) });
 
   # Find first value that contains the word "mojo"
   my $interesting = $collection->first(qr/mojo/i);
@@ -208,11 +223,17 @@ all elements.
 
   my $new = $collection->grep(qr/foo/);
   my $new = $collection->grep(sub {...});
+  my $new = $collection->grep($method);
+  my $new = $collection->grep($method, @args);
 
-Evaluate regular expression or callback for each element in collection and
-create a new collection with all elements that matched the regular expression,
-or for which the callback returned true. The element will be the first argument
-passed to the callback and is also available as C<$_>.
+Evaluate regular expression/callback for, or call method on, each element in
+collection and create a new collection with all elements that matched the
+regular expression, or for which the callback/method returned true. The element
+will be the first argument passed to the callback and is also available as
+C<$_>.
+
+  # Longer version
+  my $new = $collection->grep(sub { $_->$method(@args) });
 
   # Find all values that contain the word "mojo"
   my $interesting = $collection->grep(qr/mojo/i);
@@ -325,12 +346,23 @@ Turn collection into array reference.
 =head2 uniq
 
   my $new = $collection->uniq;
+  my $new = $collection->uniq(sub {...});
+  my $new = $collection->uniq($method);
+  my $new = $collection->uniq($method, @args);
 
-Create a new collection without duplicate elements.
+Create a new collection without duplicate elements, using the string
+representation of either the elements or the return value of the
+callback/method.
+
+  # Longer version
+  my $new = $collection->uniq(sub { $_->$method(@args) });
 
   # "foo bar baz"
   Mojo::Collection->new('foo', 'bar', 'bar', 'baz')->uniq->join(' ');
 
+  # "[[1, 2], [2, 1]]"
+  Mojo::Collection->new([1, 2], [2, 1], [3, 2])->uniq(sub{ $_->[1] })->to_array;
+
 =head1 SEE ALSO
 
 L<Mojolicious>, L<Mojolicious::Guides>, L<http://mojolicio.us>.
