@@ -7,7 +7,8 @@ use File::Spec::Functions qw(catdir catfile splitdir);
 use Mojo::Exception;
 use Mojo::Util qw(b64_decode class_to_path);
 
-our @EXPORT_OK = qw(data_section file_is_binary find_modules load_class);
+our @EXPORT_OK
+  = qw(data_section file_is_binary find_modules find_packages load_class);
 
 my (%BIN, %CACHE);
 
@@ -33,6 +34,12 @@ sub find_modules {
   return sort keys %modules;
 }
 
+sub find_packages {
+  my $ns = shift;
+  no strict 'refs';
+  return sort map { /^(.+)::$/ ? "${ns}::$1" : () } keys %{"${ns}::"};
+}
+
 sub load_class {
   my $class = shift;
 
@@ -140,6 +147,7 @@ individually.
 Extract embedded file from the C<DATA> section of a class, all files will be
 cached once they have been accessed for the first time.
 
+  # List embedded files
   say for keys %{data_section 'Foo::Bar'};
 
 =head2 file_is_binary
@@ -148,6 +156,12 @@ cached once they have been accessed for the first time.
 
 Check if embedded file from the C<DATA> section of a class was Base64 encoded.
 
+=head2 find_packages
+
+  my @pkgs = find_packages 'MyApp::Namespace';
+
+Search for packages in a namespace non-recursively.
+
 =head2 find_modules
 
   my @modules = find_modules 'MyApp::Namespace';
@@ -158,9 +172,12 @@ Search for modules in a namespace non-recursively.
 
   my $e = load_class 'Foo::Bar';
 
-Load a class and catch exceptions. Note that classes are checked for a C<new>
-method to see if they are already loaded.
+Load a class and catch exceptions, returns a false value if loading was
+successful, a true value if the class has already been loaded, or a
+L<Mojo::Exception> object if loading failed. Note that classes are checked for a
+C<new> method to see if they are already loaded.
 
+  # Handle exceptions
   if (my $e = load_class 'Foo::Bar') {
     die ref $e ? "Exception: $e" : 'Not found!';
   }
