@@ -76,8 +76,7 @@ Mojo::Server::PSGI - PSGI server
   use Mojo::Server::PSGI;
 
   my $psgi = Mojo::Server::PSGI->new;
-  $psgi->unsubscribe('request');
-  $psgi->on(request => sub {
+  $psgi->unsubscribe('request')->on(request => sub {
     my ($psgi, $tx) = @_;
 
     # Request
