@@ -1,7 +1,7 @@
 package Mojolicious::Command::inflate;
 use Mojo::Base 'Mojolicious::Command';
 
-use Mojo::Loader;
+use Mojo::Loader qw(data_section file_is_binary);
 use Mojo::Util 'encode';
 
 has description => 'Inflate embedded files to real files';
@@ -12,12 +12,11 @@ sub run {
 
   # Find all embedded files
   my %all;
-  my $app    = $self->app;
-  my $loader = Mojo::Loader->new;
+  my $app = $self->app;
   for my $class (@{$app->renderer->classes}, @{$app->static->classes}) {
-    for my $name (keys %{$loader->data($class)}) {
-      my $data = $loader->data($class, $name);
-      $data = encode 'UTF-8', $data unless $loader->is_binary($class, $name);
+    for my $name (keys %{data_section $class}) {
+      my $data = data_section $class, $name;
+      $data = encode 'UTF-8', $data unless file_is_binary $class, $name;
       $all{$name} = $data;
     }
   }
@@ -39,7 +38,16 @@ Mojolicious::Command::inflate - Inflate command
 
 =head1 SYNOPSIS
 
-  Usage: APPLICATION inflate
+  Usage: APPLICATION inflate [OPTIONS]
+
+    ./myapp.pl inflate
+
+  Options:
+    -h, --help          Show this summary of available options
+        --home <path>   Path to home directory of your application, defaults to
+                        the value of MOJO_HOME or auto detection
+    -m, --mode <name>   Operating mode for your application, defaults to the
+                        value of MOJO_MODE/PLACK_ENV or "development"
 
 =head1 DESCRIPTION
 
